@@ -4,8 +4,6 @@ import psycopg2.extras
 from AGCoder import Coder
 from AGQueryPostgres import AGQueryPostgres
 
-dirname = os.path.dirname(__file__)
-
 #
 # Variable with all security settings for a PostgreSQL user
 # Should be kept as session variable just like the conn object
@@ -14,6 +12,7 @@ dirname = os.path.dirname(__file__)
 #
 class AGSecurityListPostgres:
     usename: str = None
+    dirname = os.getcwd()
 
     def __init__(self, usename, conn):
         self.conn = conn
@@ -243,49 +242,49 @@ class AGCreateSecurityPostgres:
 
     def create_view_user_groups(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_view_user_groups.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_view_user_groups.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_table_rights(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_table_rights.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_table_rights.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_view_rights(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_view_rights.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_view_rights.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_stored_procedure_rights(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_stored_procedure_rights.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_stored_procedure_rights.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_user_groups(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_user_groups.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_user_groups.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_table_exists(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_table_exists.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_table_exists.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
 
     def create_function_record_exists(self):
         cur = self.conn.cursor(cursor_factory=psycopg2.extras.NamedTupleCursor)
-        query = open(os.path.join(dirname, "/sql_queries/create_fn_record_exists.sql"), "r").read()
+        query = open(os.path.join(self.dirname, "/sql_queries/create_fn_record_exists.sql"), "r").read()
         cur.execute(query)
         self.conn.commit()
         cur.close()
